<?php


namespace FiloBlu\Pos\Controller\Adminhtml\Posmode;

use Magento\Framework\Stdlib\Cookie\CookieMetadataFactory;
use Magento\Framework\Stdlib\CookieManagerInterface;

class Enable extends \Magento\Backend\App\Action
{

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    public $storeManager;

    /**
     * @var \Magento\Framework\Url
     */
    public $url;

    /**
     * @var \FiloBlu\Pos\Helper\Pos
     */
    public $posHelper;


    const POS_VISIBILITY_COOKIE_NAME = 'filoblu_pos_mode';
    const POS_ID_COOKIE_NAME = 'filoblu_pos_id';
    const COOKIE_DURATION = 86400 * 90; // 90 days

    /**
     * @var CookieManagerInterface
     */
    protected $cookieManager;

    /**
     * @var CookieMetadataFactory
     */
    protected $cookieMetadataFactory;

    /**
     * Enable constructor.
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Framework\Url $url
     * @param \FiloBlu\Pos\Helper\Pos $posHelper
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Framework\Url $url,
        \FiloBlu\Pos\Helper\Pos $posHelper,
        CookieManagerInterface $cookieManager,
        CookieMetadataFactory $cookieMetadataFactory
    ) {
        $this->storeManager = $storeManager;
        $this->url = $url;
        $this->posHelper = $posHelper;
        $this->cookieManager = $cookieManager;
        $this->cookieMetadataFactory = $cookieMetadataFactory;
        parent::__construct($context);
    }

    /**
     * Execute view action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        //getting storeid and website for future uses
        $storeId = (int) $this->getRequest()->getParam('store', 0);
        $websiteId = (int) $this->getRequest()->getParam('website', 0);

        $store = $this->storeManager->getDefaultStoreView();
        $url = $this->url->setScope($store);
        $frontendDomain = parse_url($url->getBaseUrl(), PHP_URL_HOST);

        if ($this->getRequest()->getParam('device') != NULL) {
            //Single POS device visibility
            $deviceIndex = $this->getRequest()->getParam('device');
            if (is_null($deviceIndex)) { //non credo che ci entrerà mai
                $result = 'Error: Could not understand which device to enable';
                $this->getResponse()->setBody($result);
                return;
            }

            //delete the cookie
            if ($this->getRequest()->getParam('enable') != 1) {
                $metadata = $this->cookieMetadataFactory
                    ->createPublicCookieMetadata()
                    ->setDomain($frontendDomain)
                    ->setPath('/');
                $this->cookieManager->deleteCookie(self::POS_ID_COOKIE_NAME, $metadata);
                $result = 'OK';
                $this->getResponse()->setBody($result);
                return;
            }

            $deviceHash = $this->posHelper->retrieveDeviceHashByIndex($deviceIndex);
            if ($deviceHash == FALSE) {
                $result = 'Could not understand which device to enable';
                $this->getResponse()->setBody($result);
                return;
            }

            //set a cookie with the hash of the POS device id
            $metadata = $this->cookieMetadataFactory
                ->createPublicCookieMetadata()
                ->setDuration(self::COOKIE_DURATION)
                ->setDomain($frontendDomain)
                ->setPath('/');
            $this->cookieManager
                ->setPublicCookie(self::POS_ID_COOKIE_NAME, $deviceHash, $metadata);

            $result = 'OK, this browser has been enabled with that device. Please reload this page to see changes.';
            $this->getResponse()->setBody($result);
            return;

        } elseif ($this->getRequest()->getParam('visibility') != NULL) {
            //Global POS visibility
            $enableRequest = $this->getRequest()->getParam('visibility');
            if ($enableRequest == 1) {
                $isGoingToEnable = 1;
            } else {
                $isGoingToEnable = 0;
            }

            $metadata = $this->cookieMetadataFactory
                ->createPublicCookieMetadata()
                ->setDuration(self::COOKIE_DURATION)
                ->setDomain($frontendDomain)
                ->setPath('/');
            $this->cookieManager
                ->setPublicCookie(self::POS_VISIBILITY_COOKIE_NAME, $isGoingToEnable, $metadata);

            $result = ($isGoingToEnable) ? 'OK. Browser enabled.' : 'OK. Browser disabled.';
            $this->getResponse()->setBody($result);
            return;
        }
    }
}