<?php


namespace FiloBlu\Pos\Helper;

use Magento\Framework\App\Helper\AbstractHelper;

class Pos extends AbstractHelper
{

    const DEVICE_LIST_CONFIG_PATH = 'filoblu_pos/general/pos_devices';
    const MULTIPLE_POS_CONFIG_PATH = 'filoblu_pos/general/multiple_pos';
    const POS_ID_COOKIE_NAME = 'filoblu_pos_id';

    protected $encryptor;
    protected $cookieManager;

    /**
     * @param \Magento\Framework\App\Helper\Context $context
     */
    public function __construct(
        \Magento\Framework\Encryption\EncryptorInterface $encryptor,
        \Magento\Framework\Stdlib\CookieManagerInterface $cookieManager,
        \Magento\Framework\App\Helper\Context $context
    ) {
        $this->encryptor = $encryptor;
        $this->cookieManager = $cookieManager;
        parent::__construct($context);
    }

    public function retrieveDeviceList() {
        $deviceList = [];
        $rawList = preg_split("/\n/", $this->scopeConfig->getValue(self::DEVICE_LIST_CONFIG_PATH, \Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE));
        foreach ($rawList as $element) {
            $element = trim($element);
            if ($element != '') {
                $deviceList[] = $element;
            }
        }
        return $deviceList;
    }

    public function retrieveDeviceHashByIndex($deviceIndex) {
        $deviceList = $this->retrieveDeviceList();
        if (isset($deviceList[$deviceIndex])) {
            return $this->encryptor->hash($deviceList[$deviceIndex]);
        } else {
            return FALSE;
        }
    }


    public function retrieveDeviceFromCookie() {
        $deviceHash = $this->cookieManager->getCookie(self::POS_ID_COOKIE_NAME, FALSE);
        if ($deviceHash == FALSE) {
            return FALSE;
        }
        foreach ($this->retrieveDeviceList() as $device) {
            if ($this->encryptor->validateHash($device, $deviceHash)) {
                return $device;
            }
        }
        return FALSE;
    }

    public function isMultiPosEnabled($store_id = null) {
        return $this->scopeConfig->isSetFlag(self::MULTIPLE_POS_CONFIG_PATH, \Magento\Store\Model\ScopeInterface::SCOPE_STORE, $store_id);
    }
}